@@ -1,6 +1,6 @@
 package WWW::GoKGS::Scraper::TournLinks;
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Exporter qw/import/;
 use Web::Scraper;
 
@@ -8,10 +8,7 @@ our @EXPORT_OK = qw( process_links );
 
 sub process_links {
     my %filter = @_;
-
-    my $round_number = sub {
-        m/^Round (\d+) / ? int $1 : undef;
-    };
+    my $round = sub { m/^Round (\d+) / ? int $1 : undef };
 
     my @start_time = (
         sub {
@@ -32,23 +29,17 @@ sub process_links {
         @{ $filter{'links.rounds[].end_time'} || [] },
     );
 
-    my $round = scraper {
-        process '.', 'round' => [ 'TEXT', $round_number ];
-        process '.', 'start_time' => [ 'TEXT', @start_time ];
-        process 'a', 'end_time' => [ 'TEXT', @end_time ];
-        process 'a', 'uri' => '@href';
-    };
-
-    my $entrant = scraper {
-        process 'a', 'sort_by' => [ 'TEXT', sub { s/^By // } ];
-        process 'a', 'uri' => '@href';
-    };
-
     process '//div[@class="tournData"]', 'links' => scraper {
         process '//ul[starts-with(preceding-sibling::p/text(), "Entrants")]//li',
-                'entrants[]' => $entrant;
+                'entrants[]' => scraper {
+                    process 'a', 'sort_by' => [ 'TEXT', sub { s/^By // } ];
+                    process 'a', 'uri' => '@href'; };
         process '//ul[starts-with(preceding-sibling::p/text(), "Games")]//li',
-                'rounds[]' => $round;
+                'rounds[]' => scraper {
+                    process '.', 'round' => [ 'TEXT', $round ];
+                    process '.', 'start_time' => [ 'TEXT', @start_time ];
+                    process 'a', 'end_time' => [ 'TEXT', @end_time ];
+                    process 'a', 'uri' => '@href'; };
     };
 }
 
